@@ -61,8 +61,8 @@ class PerturbFlow(nn.Module):
                  cell_factor_size: int = 0,
                  supervised_mode: bool = False,
                  z_dim: int = 10,
-                 z_dist: Literal['normal','studentt','laplacian','cauchy','gumbel'] = 'normal',
-                 loss_func: Literal['negbinomial','poisson','multinomial','bernoulli'] = 'multinomial',
+                 z_dist: Literal['normal','studentt','laplacian','cauchy','gumbel'] = 'gumbel',
+                 loss_func: Literal['negbinomial','poisson','multinomial','bernoulli'] = 'poisson',
                  inverse_dispersion: float = 10.0,
                  use_zeroinflate: bool = False,
                  hidden_layers: list = [300],
@@ -71,7 +71,7 @@ class PerturbFlow(nn.Module):
                  post_layer_fct: list = ['layernorm'],
                  post_act_fct: list = None,
                  config_enum: str = 'parallel',
-                 use_cuda: bool = False,
+                 use_cuda: bool = True,
                  seed: int = 42,
                  zero_bias: bool|list = True,
                  dtype = torch.float32, # type: ignore
@@ -877,12 +877,13 @@ class PerturbFlow(nn.Module):
             #counts = self.sigmoid(concentrate)
             counts = dist.Bernoulli(logits=concentrate).to_event(1).mean
         elif self.loss_func == 'negbinomial':
-            #counts = concentrate.exp()
-            #rate = concentrate.exp()
-            #theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
+            rate = concentrate.exp()
+            theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
             
             total_count = pyro.param("inverse_dispersion")
-            counts = dist.NegativeBinomial(total_count=total_count, logits=concentrate).to_event(1).mean
+            #store = pyro.get_param_store()
+            #total_count = store['inverse_dispersion']
+            counts = dist.NegativeBinomial(total_count=total_count, probs=theta).to_event(1).mean
         elif self.loss_func == 'poisson':
             rate = concentrate.exp()
             theta = dist.DirichletMultinomial(total_count=1, concentration=rate).mean
@@ -927,8 +928,6 @@ class PerturbFlow(nn.Module):
         E = []
         with tqdm(total=len(dataloader), desc='', unit='batch') as pbar:
             for Z_batch, L_batch, _ in dataloader:
-                if self.loss_func not in ['multinomial','poisson']:
-                    L_batch = None
                 concentrate = self._get_expression_response(Z_batch)
                 if use_sampler:
                     counts = self._count_sample(concentrate)
