@@ -241,4 +241,38 @@ class ZeroBiasMLP(nn.Module):
         mask = torch.zeros_like(y)
         mask[x[1][:,0]>0,:] = 1
         return y*mask
-        
\ No newline at end of file
+        
+
+class HDMLP(nn.Module):
+    def __init__(
+        self,
+        input_size,
+        hidden_sizes,
+        output_depth,
+        activation=nn.ReLU,
+        output_activation=None,
+        post_layer_fct=lambda layer_ix, total_layers, layer: None,
+        post_act_fct=lambda layer_ix, total_layers, layer: None,
+        allow_broadcast=False,
+        use_cuda=False,
+    ):
+        # init the module object
+        super().__init__()
+        self.mlp = MLP(mlp_sizes=[1] + hidden_sizes + [output_depth],
+                       activation=activation,
+                       output_activation=output_activation,
+                       post_layer_fct=post_layer_fct,
+                       post_act_fct=post_act_fct,
+                       allow_broadcast=allow_broadcast,
+                       use_cuda=use_cuda,
+                       bias=True)
+        self.input_size=input_size
+        self.output_depth=output_depth
+        
+    # pass through our sequential for the output!
+    def forward(self, x):
+        batch_size, n = x.shape
+        x = x.view(batch_size * n, 1)
+        out = self.mlp(x)
+        out = out.view(batch_size, n, self.output_depth)
+        return out
\ No newline at end of file
